##' @importFrom magrittr %>%
##' @export
magrittr::`%>%`

##' @importFrom magrittr %<>%
##' @export
magrittr::`%<>%`

##' @importFrom tibble as_tibble
##' @export
tibble::as_tibble

##' @importFrom tibble tibble
##' @export
tibble::tibble


##' @importFrom dplyr filter
##' @export
dplyr::filter

##' @importFrom dplyr arrange
##' @export
dplyr::arrange

##' @importFrom dplyr select
##' @export
dplyr::select

##' @importFrom dplyr rename
##' @export
dplyr::rename

##' @importFrom dplyr mutate
##' @export
dplyr::mutate

##' @importFrom dplyr transmute
##' @export
dplyr::transmute

##' @importFrom dplyr summarise
##' @export
dplyr::summarise

##' @importFrom dplyr summarize
##' @export
dplyr::summarize


##' @importFrom dplyr full_join
##' @export
dplyr::full_join

##' @importFrom rlang .data
##' @export
rlang::.data
